"""
    otmixmod --- The Mixmod interface for Open TURNS
    ===================================================

    Contents
    --------
      'otmixmod' is a python module for Open TURNS that allows to use
      the Mixmod software to build Open TURNS objects.

"""

import sys
if sys.platform.startswith('win'):
    # this ensures OT dll is loaded
    import openturns

from .otmixmod import *

__version__ = '0.12'



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""otmixmod module"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _otmixmod
else:
    import _otmixmod

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


import openturns.base
import openturns.common
import openturns.typ
import openturns.statistics
import openturns.graph
import openturns.func
import openturns.geom
import openturns.diff
import openturns.optim
import openturns.experiment
import openturns.solver
import openturns.algo
import openturns.uncertainty
import openturns.model_copula
import openturns.randomvector
import openturns.dist_bundle1
import openturns.dist_bundle2
import openturns.weightedexperiment
import openturns.classification
import openturns.orthogonalbasis
import openturns.metamodel
import openturns.transformation
import openturns.analytical
import openturns.simulation
import openturns.stattests
import openturns.model_process
import openturns.dist_bundle3
class MixtureFactory(openturns.model_copula.DistributionFactoryImplementation):
    r"""Proxy of C++ OTMIXMOD::MixtureFactory class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def getClassName(self):
        r"""
        getClassName(MixtureFactory self) -> OT::String
        Accessor to the object's name.

        Returns
        -------
        class_name : str
            The object class name (`object.__class__.__name__`).
        """
        return _otmixmod.MixtureFactory_getClassName(self)

    def build(self, *args):
        r"""
        build(MixtureFactory self, Sample sample) -> Distribution
        build(MixtureFactory self, Point parameters) -> Distribution
        build(MixtureFactory self, Sample sample) -> Distribution
        build(MixtureFactory self) -> Distribution
        Build the distribution.

        **Available usages**:

            build(*sample*)

            build(*param*)

        Parameters
        ----------
        sample : 2-d sequence of float
            Sample from which the distribution parameters are estimated.
        param : Collection of :class:`~openturns.PointWithDescription`
            A vector of parameters of the distribution.

        Returns
        -------
        dist : :class:`~openturns.Distribution`
            The built distribution.
        """
        return _otmixmod.MixtureFactory_build(self, *args)

    def buildAsMixture(self, sample):
        r"""buildAsMixture(MixtureFactory self, Sample sample) -> Mixture"""
        return _otmixmod.MixtureFactory_buildAsMixture(self, sample)

    def setAtomsNumber(self, number):
        r"""setAtomsNumber(MixtureFactory self, OT::UnsignedInteger const & number)"""
        return _otmixmod.MixtureFactory_setAtomsNumber(self, number)

    def getAtomsNumber(self):
        r"""getAtomsNumber(MixtureFactory self) -> OT::UnsignedInteger"""
        return _otmixmod.MixtureFactory_getAtomsNumber(self)

    def setCovarianceModel(self, covarianceModel):
        r"""setCovarianceModel(MixtureFactory self, OT::String const covarianceModel)"""
        return _otmixmod.MixtureFactory_setCovarianceModel(self, covarianceModel)

    def getCovarianceModel(self):
        r"""getCovarianceModel(MixtureFactory self) -> OT::String"""
        return _otmixmod.MixtureFactory_getCovarianceModel(self)

    @staticmethod
    def BuildClusters(data, labels, nbClusters):
        r"""BuildClusters(Sample data, Indices labels, OT::UnsignedInteger const nbClusters) -> SampleCollection"""
        return _otmixmod.MixtureFactory_BuildClusters(data, labels, nbClusters)

    def setState(self, yState, zState):
        r"""setState(MixtureFactory self, OT::UnsignedInteger const yState, OT::UnsignedInteger const zState)"""
        return _otmixmod.MixtureFactory_setState(self, yState, zState)

    def __init__(self, *args):
        r"""
        __init__(MixtureFactory self) -> MixtureFactory
        __init__(MixtureFactory self, OT::UnsignedInteger const atomsNumber, OT::String const covarianceModel="Gaussian_pk_Lk_C") -> MixtureFactory
        __init__(MixtureFactory self, MixtureFactory other) -> MixtureFactory
        """
        _otmixmod.MixtureFactory_swiginit(self, _otmixmod.new_MixtureFactory(*args))
    __swig_destroy__ = _otmixmod.delete_MixtureFactory

# Register MixtureFactory in _otmixmod:
_otmixmod.MixtureFactory_swigregister(MixtureFactory)

def MixtureFactory_BuildClusters(data, labels, nbClusters):
    r"""MixtureFactory_BuildClusters(Sample data, Indices labels, OT::UnsignedInteger const nbClusters) -> SampleCollection"""
    return _otmixmod.MixtureFactory_BuildClusters(data, labels, nbClusters)

class MixtureClassifierFactory(openturns.common.Object):
    r"""Proxy of C++ OTMIXMOD::MixtureClassifierFactory class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def getClassName(self):
        r"""
        getClassName(MixtureClassifierFactory self) -> OT::String
        Accessor to the object's name.

        Returns
        -------
        class_name : str
            The object class name (`object.__class__.__name__`).
        """
        return _otmixmod.MixtureClassifierFactory_getClassName(self)

    def build(self, sample):
        r"""build(MixtureClassifierFactory self, Sample sample) -> MixtureClassifier"""
        return _otmixmod.MixtureClassifierFactory_build(self, sample)

    def getMixtureFactory(self):
        r"""getMixtureFactory(MixtureClassifierFactory self) -> MixtureFactory"""
        return _otmixmod.MixtureClassifierFactory_getMixtureFactory(self)

    def setMixtureFactory(self, mixtureFactory):
        r"""setMixtureFactory(MixtureClassifierFactory self, MixtureFactory mixtureFactory)"""
        return _otmixmod.MixtureClassifierFactory_setMixtureFactory(self, mixtureFactory)

    def __init__(self, *args):
        r"""
        __init__(MixtureClassifierFactory self) -> MixtureClassifierFactory
        __init__(MixtureClassifierFactory self, MixtureFactory mixtureFactory) -> MixtureClassifierFactory
        __init__(MixtureClassifierFactory self, MixtureClassifierFactory other) -> MixtureClassifierFactory
        """
        _otmixmod.MixtureClassifierFactory_swiginit(self, _otmixmod.new_MixtureClassifierFactory(*args))
    __swig_destroy__ = _otmixmod.delete_MixtureClassifierFactory

# Register MixtureClassifierFactory in _otmixmod:
_otmixmod.MixtureClassifierFactory_swigregister(MixtureClassifierFactory)



